==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/properties/StyleNumberPropertiesBase.java <==
package com.openexchange.office.filter.odf.properties;

import java.util.Iterator;
import org.apache.xml.serializer.SerializationHandler;
import org.json.JSONObject;
import org.odftoolkit.odfdom.IElementWriter;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.DLList;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odf.styles.StyleManager;

public abstract class StyleNumberPropertiesBase extends StylePropertiesBase {

	public StyleNumberPropertiesBase(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public void writeObject(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.startElement(output, getNamespace(), getLocalName(), getQName());
		attributes.write(output);
		if(!text.isEmpty()) {
			output.characters(text);
		}
		final DLList<IElementWriter> content = getContent();
		if(content!=null) {
			final Iterator<IElementWriter> childIter = content.iterator();
			while(childIter.hasNext()) {
				childIter.next().writeObject(output);
			}
		}
		SaxContextHandler.endElement(output, getNamespace(), getLocalName(), getQName());

	}

	@Override
	public final void applyAttrs(StyleManager styleManager, JSONObject attrs) {
	    //
	}

	@Override
	public final void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
	    //
	}
}

==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/odf/properties/StyleNumberPropertiesBase.java <==
package com.openexchange.office.filter.odf.properties;

import java.util.Iterator;
import org.apache.xml.serializer.SerializationHandler;
import org.json.JSONObject;
import org.odftoolkit.odfdom.IElementWriter;
import org.xml.sax.SAXException;
import com.openexchange.office.filter.core.DLList;
import com.openexchange.office.filter.odf.AttributesImpl;
import com.openexchange.office.filter.odf.OpAttrs;
import com.openexchange.office.filter.odf.SaxContextHandler;
import com.openexchange.office.filter.odf.styles.StyleManager;

public abstract class StyleNumberPropertiesBase extends StylePropertiesBase {

	public StyleNumberPropertiesBase(AttributesImpl attributesImpl) {
		super(attributesImpl);
	}

	@Override
	public void writeObject(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.startElement(output, getNamespace(), getLocalName(), getQName());
		attributes.write(output);
		if(!text.isEmpty()) {
			output.characters(text);
		}
		final DLList<IElementWriter> content = getContent();
		if(content!=null) {
			final Iterator<IElementWriter> childIter = content.iterator();
			while(childIter.hasNext()) {
				childIter.next().writeObject(output);
			}
		}
		SaxContextHandler.endElement(output, getNamespace(), getLocalName(), getQName());

	}

	@Override
	public final void applyAttrs(StyleManager styleManager, JSONObject attrs) {
	    //
	}

	@Override
	public final void createAttrs(StyleManager styleManager, boolean contentAutoStyle, OpAttrs attrs) {
	    //
	}
}
